@@ -1887,13 +1887,13 @@ DWORD MPPASMCALL X86_Convert32To24(LPVOID lp16, int *pBuffer, DWORD lSampleCount
 			vumax = n;
 		p = n >> (8-MIXING_ATTENUATION) ; // 24-bit signed
 #ifdef WORDS_BIGENDIAN
-		buf[i*3+0] = p & 0xFF0000 ;
-		buf[i*3+1] = p & 0x00FF00 ;
+		buf[i*3+0] = p & 0xFF0000 >> 24;
+		buf[i*3+1] = p & 0x00FF00 >> 16 ;
 		buf[i*3+2] = p & 0x0000FF ;
 #else
 		buf[i*3+0] = p & 0x0000FF ;
-		buf[i*3+1] = p & 0x00FF00 ;
-		buf[i*3+2] = p & 0xFF0000 ;
+		buf[i*3+1] = p & 0x00FF00 >> 16;
+		buf[i*3+2] = p & 0xFF0000 >> 24;
 #endif
 	}
 	*lpMin = vumin;
@@ -1970,7 +1970,7 @@ DWORD MPPASMCALL X86_Convert32To32(LPVOID lp16, int *pBuffer, DWORD lSampleCount
 {
 	UINT i ;
 	int vumin = *lpMin, vumax = *lpMax;
-	signed long *p = (signed long *)lp16;
+	int32_t *p = (int32_t *)lp16;
 	
 	for ( i=0; i<lSampleCount; i++)
 	{
@@ -2337,7 +2337,7 @@ UINT MPPASMCALL X86_AGC(int *pBuffer, UINT nSamples, UINT nAGC)
 
 	while(nSamples)
 	{
-		x = ((long long int)(*pBuffer) * nAGC) >> AGC_PRECISION;
+		x = ((int64_t)(*pBuffer) * nAGC) >> AGC_PRECISION;
 
 		if((x < MIXING_LIMITMIN) || (x > MIXING_LIMITMAX))
 		nAGC--;
